@@ -32,12 +32,18 @@
 
 #define QT_FEATURE_cxx2a -1
 
+#define QT_FEATURE_cxx2b -1
+
 #define QT_FEATURE_c99 1
 
 #define QT_FEATURE_c11 1
 
+#define QT_FEATURE_reduce_relocations 1
+
 #define QT_FEATURE_signaling_nan 1
 
+#define QT_FEATURE_zstd 1
+
 #define QT_FEATURE_thread 1
 
 #define QT_FEATURE_future 1
@@ -47,13 +53,13 @@
 #define QT_FEATURE_dbus 1
 
 
-#define QT_VERSION_STR "6.2.1"
+#define QT_VERSION_STR "6.4.0"
 
 #define QT_VERSION_MAJOR 6
 
-#define QT_VERSION_MINOR 2
+#define QT_VERSION_MINOR 4
 
-#define QT_VERSION_PATCH 1
+#define QT_VERSION_PATCH 0
 #define QT_LARGEFILE_SUPPORT 64
 #define QT_VISIBILITY_AVAILABLE
 #define QT_REDUCE_RELOCATIONS
@@ -74,8 +80,9 @@
 #define QT_COMPILER_SUPPORTS_AVX512VL 1
 #define QT_COMPILER_SUPPORTS_AVX512IFMA 1
 #define QT_COMPILER_SUPPORTS_AVX512VBMI 1
+#define QT_COMPILER_SUPPORTS_AVX512VBMI2 1
 #define QT_COMPILER_SUPPORTS_AES 1
+#define QT_COMPILER_SUPPORTS_VAES 1
 #define QT_COMPILER_SUPPORTS_RDRND 1
 #define QT_COMPILER_SUPPORTS_RDSEED 1
 #define QT_COMPILER_SUPPORTS_SHA 1
-#define QT_COMPILER_SUPPORTS_SIMD_ALWAYS 1
